﻿using System;
using System.Configuration;
using System.IO;
using System.Reflection;
using System.Runtime.CompilerServices;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using System.Windows.Markup;
using System.Windows.Media;

namespace EZUpdater
{
    public class Config
    {
        private static Window configWindow;

        private static Config _instance;
        public static Config Instance { get { return _instance ?? (_instance = new Config()); } set { _instance = value; } }

        public static void CloseWindow()
        {
            configWindow.Close();
        }

        public static Window GetDisplayWindow()
        {
            try
            {
                if (configWindow == null)
                {
                    configWindow = new Window();
                }

                string assemblyPath = Path.GetDirectoryName(Assembly.GetEntryAssembly().Location);
                string assemblyName = Assembly.GetExecutingAssembly().GetName().Name;
                string xamlPath = Path.Combine(assemblyPath, "Plugins", "EZUpdater", "Config.xaml");

                string xamlContent = File.ReadAllText(xamlPath);
                // Change reference to custom class
                xamlContent = xamlContent.Replace(
                    "xmlns:ez=\"clr-namespace:EZUpdater\"",
                    "xmlns:ez=\"clr-namespace:EZUpdater;assembly=" + assemblyName + "\"");

                // This hooks up our object with our UserControl DataBinding
                configWindow.DataContext = Instance;

                UserControl mainControl = (UserControl)XamlReader.Load(new MemoryStream(Encoding.UTF8.GetBytes(xamlContent)));
                configWindow.Content = mainControl;
                configWindow.Width = 850;
                configWindow.Height = 400;
                configWindow.ResizeMode = ResizeMode.CanResizeWithGrip;
                configWindow.Background = Brushes.LightGray;

                configWindow.Title = "EZUpdater";

                configWindow.Closed += ConfigWindow_Closed;
                Application.Current.Exit += ConfigWindow_Closed;
            }
            catch (Exception ex)
            {
                Logger.Error(ex.ToString());
            }
            return configWindow;
        }

        public Config()
        {

        }

        public EZSettings Settings { get { return EZSettings.Instance; } set { EZSettings.Instance = value; } }

        public ICommand CheckUpdatesCommand
        {
            get
            {
                return new RelayCommand((parameter) =>
                {
                    try
                    {
                        CheckUpdates();
                    }
                    catch (Exception ex)
                    {
                        Logger.Error("Error Checking For Updates", ex);
                    }
                });
            }
        }

        public ICommand ResetDefaultsCommand
        {
            get
            {
                return new RelayCommand((parameter) =>
                {
                    try
                    {
                        EZSettings.Instance.InitializeDefaults();
                    }
                    catch (Exception ex)
                    {
                        Logger.Error("Error Initializing Defaults", ex);
                    }
                });
            }
        }

        public ICommand SaveCommand
        {
            get
            {
                return new RelayCommand((parameter) =>
                {
                    try
                    {
                        EZSettings.Instance.Save();
                        configWindow.Close();
                    }
                    catch (Exception ex)
                    {
                        Logger.Error("Error Initializing Defaults", ex);
                    }
                });
            }
        }

        public void CheckUpdates()
        {
            foreach (var repo in EZSettings.Instance.Repositories)
            {
                repo.LastUpdate = DateTime.MinValue;
            }
        }

        static void ConfigWindow_Closed(object sender, System.EventArgs e)
        {
            EZSettings.Instance.Save();
            if (configWindow != null)
            {
                configWindow.Closed -= ConfigWindow_Closed;
                configWindow = null;
            }
        }

    
    }
}
