﻿using System;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using Zeta.Common.Xml;
using Zeta.XmlEngine;

namespace EZUpdater
{
    [XmlElement("EZUpdater")]
    public class EZSettings : XmlSettings
    {
        private static EZSettings _instance;

        public EZSettings() :
            base(Path.Combine(SettingsDirectory, "EZUpdater", "EZUpdater.xml"))
        {
        }

        public static EZSettings Instance
        {
            get { return _instance ?? (_instance = new EZSettings()); }
            set { _instance = value; }
        }

        [XmlElement("Repositories")]
        private Repository[] RepositoryArray { get; set; }

        private ObservableCollection<Repository> _repositories;

        public ObservableCollection<Repository> Repositories
        {
            get
            {
                if (RepositoryArray == null)
                {
                    InitializeDefaults();
                }
                if (_repositories == null)
                    _repositories = new ObservableCollection<Repository>(RepositoryArray);
                return _repositories;
            }
            set
            {
                _repositories = value;
                RepositoryArray = _repositories.ToArray();
                OnPropertyChanged("Repositories");
            }
        }
        internal void InitializeDefaults()
        {
            try
            {
                Instance.Repositories = Repository.GetDefaultRepositories();
                Instance.Save();
            }
            catch (Exception ex)
            {
                Logger.Error("Exception initializing default settings: {0}", ex.ToString());
            }
        }

        public override void Save()
        {
            if (_repositories != null)
                RepositoryArray = _repositories.ToArray();
            base.Save();
        }
    }
}
