﻿using System;
using System.IO;
using System.Linq;

namespace EZUpdater
{
    public class FileUtils
    {
        //Source: http://msdn.microsoft.com/en-us/library/bb762914(v=vs.110).aspx
        internal static void DirectoryCopy(string sourceDirName, string destDirName, bool copySubDirs, params string[] ignoreNames)
        {
            bool copySuccessful = false;
            while (!copySuccessful)
            {
                try
                {
                    // Get the subdirectories for the specified directory.
                    DirectoryInfo sourceDir = new DirectoryInfo(sourceDirName);
                    DirectoryInfo[] dirs = sourceDir.GetDirectories();

                    if (!sourceDir.Exists)
                    {
                        throw new DirectoryNotFoundException(
                            "Source directory does not exist or could not be found: "
                            + sourceDirName);
                    }

                    // If the destionation directory exists, delete it so we get a fresh copy
                    if (Directory.Exists(destDirName))
                    {
                        Directory.Delete(destDirName, true);
                    }
                    // Create the new directory 
                    if (!Directory.Exists(destDirName))
                    {
                        Directory.CreateDirectory(destDirName);
                    }

                    // Get the files in the directory and copy them to the new location.
                    FileInfo[] files = sourceDir.GetFiles();
                    foreach (FileInfo file in files)
                    {
                        if (ignoreNames.Contains(file.Name))
                            continue;
                        string temppath = Path.Combine(destDirName, file.Name);

                        // Create the new directory 
                        if (!Directory.Exists(destDirName))
                        {
                            Directory.CreateDirectory(destDirName);
                        }

                        file.CopyTo(temppath, true);
                    }

                    // If copying subdirectories, copy them and their contents to new location. 
                    if (copySubDirs)
                    {
                        foreach (DirectoryInfo subdir in dirs)
                        {
                            if (ignoreNames.Contains(subdir.Name))
                                continue;

                            string temppath = Path.Combine(destDirName, subdir.Name);
                            DirectoryCopy(subdir.FullName, temppath, copySubDirs, ignoreNames);
                        }
                    }

                    copySuccessful = true;
                }
                catch (Exception ex)
                {
                    Logger.Error("Error in file copy: {0}", ex.Message);
                }
                
            }
            //Logger.Debug("Directory copy successful for {0} to {1}", sourceDirName, destDirName);            
        }
    }
}
