using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Security;
using Zeta.XmlEngine;

namespace EZUpdater
{
    public enum RepoKind
    {
        Plugin,
        Profile
    }

    [XmlElement("Repository")]
    public class Repository : INotifyPropertyChanged
    {

        private RepoKind _kind;
        private string _name;
        private string _repoUrl;
        private string _sourceDirectory;
        private bool _enabled;
        private DateTime _lastUpdate;

        /// <summary>
        /// "Plugin" or "Profile"
        /// </summary>
        [XmlElement("Kind")]
        public RepoKind Kind
        {
            get { return _kind; }
            set
            {
                if (value == _kind)
                    return;
                _kind = value;
                OnPropertyChanged("Kind");
            }
        }

        [XmlElement("Name")]
        public string Name
        {
            get { return _name; }
            set
            {
                if (value == _name)
                    return;
                _name = value;
                OnPropertyChanged("Name");
            }
        }

        [XmlElement("RepoURL")]
        public string RepoURL
        {
            get { return _repoUrl; }
            set
            {
                if (value == _repoUrl)
                    return;
                _repoUrl = value;
                OnPropertyChanged("RepoURL");
            }
        }


        [XmlElement("SourceDirectory")]
        public string SourceDirectory
        {
            get { return _sourceDirectory; }
            set
            {
                if (value == _sourceDirectory)
                    return;
                _sourceDirectory = value;
                OnPropertyChanged("SourceDirectory");
            }
        }


        [XmlElement("Enabled")]
        public bool Enabled
        {
            get { return _enabled; }
            set
            {
                if (value == _enabled)
                    return;
                _enabled = value;
                OnPropertyChanged("Enabled");
            }
        }


        [XmlElement("LastUpdate")]
        public DateTime LastUpdate
        {
            get { return _lastUpdate; }
            set
            {
                if (value == _lastUpdate)
                    return;
                _lastUpdate = value;
                OnPropertyChanged("LastUpdate");
            }
        }


        public Repository()
        {

        }

        internal static ObservableCollection<Repository> GetDefaultRepositories()
        {
            return new ObservableCollection<Repository>
            {
                TrinityDefault(),
                QuestToolsDefault(),
				AdventurerDefault()
            };
        }

        private static Repository TrinityDefault()
        {
            return new Repository
            {
                Kind = RepoKind.Plugin,
                Name = "Trinity",
                RepoURL = "네이버카페 참조해주세요",
                Enabled = true,
                LastUpdate = new DateTime()
            };
        }

        private static Repository QuestToolsDefault() 
        {
            return new Repository
            {
                Kind = RepoKind.Plugin,
                Name = "QuestTools",
                RepoURL = "네이버카페 참조해주세요",
                SourceDirectory = "trunk\\",
                Enabled = true,
                LastUpdate = new DateTime()
            };
        }

	private static Repository AdventurerDefault()
        {
            return new Repository
            {
                Kind = RepoKind.Plugin,
                Name = "Adventurer",
                RepoURL = "네이버카페 참조해주세요",
                Enabled = true,
                LastUpdate = new DateTime()
            };
        }

        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// Called when property changed.
        /// </summary>
        /// <param name="propertyName">Name of the property.</param>
        private void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }


    }
}
